"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var kebabCase = function (str) {
    return str
        .replace(/([a-z])([A-Z])/g, '$1-$2')
        .replace(/\s+/g, '-')
        .toLowerCase();
};
var mapProperties = function (properties) {
    return Object.keys(properties).map(function (property) { return kebabCase(property) + ":" + properties[property]; });
};
var getMountedProperties = function () {
    return Array.from(document.styleSheets)
        .map(function (sheet) {
        // @ts-ignore
        return sheet.cssRules.map(function (rule) { return rule.style.cssText; });
    })
        .join(' ');
};
var containsClassNames = function (classNames, css) {
    return classNames.reduce(function (accum, className) { return (css.includes("." + className) ? true : accum); }, false);
};
function toHaveCompiledCss(element) {
    var _a;
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    var property = args[0], value = args[1];
    var properties = typeof property === 'string' ? (_a = {}, _a[property] = value, _a) : property;
    var inlineStyleTag = element.parentElement && element.parentElement.querySelector('style');
    var styleElements = inlineStyleTag != null ? [inlineStyleTag] : Array.from(document.head.querySelectorAll('style'));
    if (!styleElements) {
        return {
            pass: false,
            message: function () { return 'pairing style element was not found'; },
        };
    }
    var stylesToFind = mapProperties(properties);
    var foundStyles = [];
    var classNames = element.className.split(' ');
    var _loop_1 = function (styleElement) {
        var css = styleElement.textContent || '';
        // This is a hack to get ahold of the styles.
        // Unfortunately JSDOM doesn't handle css variables properly
        // See: https://github.com/jsdom/jsdom/issues/1895
        // @ts-ignore
        var styles = element[Object.keys(element)[0]].memoizedProps.style;
        if (styles && Object.keys(styles).length > 0) {
            Object.entries(styles).forEach(function (_a) {
                var key = _a[0], value = _a[1];
                // Replace all instances of var with the value.
                // We split and join to replace all instances without needing to jump into a dynamic regex.
                css = css.split("var(" + key + ")").join(value);
            });
        }
        if (containsClassNames(classNames, css)) {
            foundStyles.push.apply(foundStyles, stylesToFind.filter(function (styleToFind) { return css.includes(styleToFind); }));
        }
    };
    for (var _b = 0, styleElements_1 = styleElements; _b < styleElements_1.length; _b++) {
        var styleElement = styleElements_1[_b];
        _loop_1(styleElement);
    }
    var notFoundStyles = stylesToFind.filter(function (style) { return !foundStyles.includes(style); });
    var foundFormatted = stylesToFind.join(', ');
    var notFoundFormatted = notFoundStyles.join(', ');
    if (foundStyles.length > 0 && notFoundStyles.length === 0) {
        return {
            pass: true,
            message: !this.isNot
                ? function () { return ''; }
                : function () {
                    return "Found \"" + foundFormatted + "\" on <" + element.nodeName.toLowerCase() + " css={`" + getMountedProperties() + "`}> element.";
                },
        };
    }
    return {
        pass: false,
        message: function () {
            return "Could not find \"" + notFoundFormatted + "\" on <" + element.nodeName.toLowerCase() + " css={`" + getMountedProperties() + "`}> element.";
        },
    };
}
exports.toHaveCompiledCss = toHaveCompiledCss;
//# sourceMappingURL=matchers.js.map